# Generated by Django 2.1.7 on 2019-02-12 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CodeRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('VALID', models.BooleanField(default=True)),
                ('mobile', models.CharField(max_length=11, verbose_name='手机号')),
                ('code', models.CharField(max_length=6, verbose_name='验证码')),
                ('tag', models.CharField(default='unkown', max_length=32, verbose_name='标签')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
